@@ -19,10 +19,11 @@ from typing import (
 from lilya import __version__
 from lilya.caches.memory import InMemoryCache
 from lilya.conf.enums import EnvironmentType
+from lilya.contrib.documentation import Doc
 from lilya.logging import LoggingConfig, StandardLoggingConfig
 from lilya.protocols.cache import CacheBackend
 from lilya.serializers import SerializerConfig, StandardSerializerConfig
-from lilya.types import ApplicationType, Dependencies, Doc, ExceptionHandler
+from lilya.types import ApplicationType, Dependencies, ExceptionHandler
 
 if TYPE_CHECKING:
     from lilya.middleware.base import DefineMiddleware
@@ -719,7 +720,7 @@ class Settings(Internal):
         return {}
 
     @property
-    def on_startup(self) -> Sequence[Callable[[], Any]]:
+    def on_startup(self) -> Sequence[Callable[[], Any]] | None:
         """
         A `list` of events that are trigger upon the application
         starts.
@@ -757,7 +758,7 @@ class Settings(Internal):
         return None
 
     @property
-    def on_shutdown(self) -> Sequence[Callable[[], Any]]:
+    def on_shutdown(self) -> Sequence[Callable[[], Any]] | None:
         """
         A `list` of events that are trigger upon the application
         shuts down.
