@@ -3,13 +3,16 @@ from ._internal.websockets import (
     WebSocketDisconnect,
     WebSocketTestSession,
 )
+from .async_client import AsyncTestClient
 from .base import TestClient
-from .helpers import create_client
+from .helpers import create_async_client, create_client
 from .utils import override_settings
 
 __all__ = [
+    "AsyncTestClient",
     "TestClient",
     "create_client",
+    "create_async_client",
     "WebSocketDenialResponse",
     "WebSocketTestSession",
     "WebSocketDisconnect",
